package com.mysql.jdbc.log;

import com.mysql.jdbc.Util;
import com.mysql.jdbc.profiler.ProfilerEvent;
import java.util.Date;

/* loaded from: com_mysql_jdbc_log.jar:com/mysql/jdbc/log/StandardLogger.class */
public class StandardLogger implements Log {
    private static final int FATAL = 0;
    private static final int ERROR = 1;
    private static final int WARN = 2;
    private static final int INFO = 3;
    private static final int DEBUG = 4;
    private static final int TRACE = 5;
    public static StringBuffer bufferedLog = null;
    private boolean logLocationInfo;

    public StandardLogger(String name) {
        this(name, false);
    }

    public StandardLogger(String name, boolean logLocationInfo) {
        this.logLocationInfo = true;
        this.logLocationInfo = logLocationInfo;
    }

    public static void saveLogsToBuffer() {
        if (bufferedLog == null) {
            bufferedLog = new StringBuffer();
        }
    }

    @Override // com.mysql.jdbc.log.Log
    public boolean isDebugEnabled() {
        return true;
    }

    @Override // com.mysql.jdbc.log.Log
    public boolean isErrorEnabled() {
        return true;
    }

    @Override // com.mysql.jdbc.log.Log
    public boolean isFatalEnabled() {
        return true;
    }

    @Override // com.mysql.jdbc.log.Log
    public boolean isInfoEnabled() {
        return true;
    }

    @Override // com.mysql.jdbc.log.Log
    public boolean isTraceEnabled() {
        return true;
    }

    @Override // com.mysql.jdbc.log.Log
    public boolean isWarnEnabled() {
        return true;
    }

    @Override // com.mysql.jdbc.log.Log
    public void logDebug(Object message) {
        logInternal(DEBUG, message, null);
    }

    @Override // com.mysql.jdbc.log.Log
    public void logDebug(Object message, Throwable exception) {
        logInternal(DEBUG, message, exception);
    }

    @Override // com.mysql.jdbc.log.Log
    public void logError(Object message) {
        logInternal(ERROR, message, null);
    }

    @Override // com.mysql.jdbc.log.Log
    public void logError(Object message, Throwable exception) {
        logInternal(ERROR, message, exception);
    }

    @Override // com.mysql.jdbc.log.Log
    public void logFatal(Object message) {
        logInternal(FATAL, message, null);
    }

    @Override // com.mysql.jdbc.log.Log
    public void logFatal(Object message, Throwable exception) {
        logInternal(FATAL, message, exception);
    }

    @Override // com.mysql.jdbc.log.Log
    public void logInfo(Object message) {
        logInternal(INFO, message, null);
    }

    @Override // com.mysql.jdbc.log.Log
    public void logInfo(Object message, Throwable exception) {
        logInternal(INFO, message, exception);
    }

    @Override // com.mysql.jdbc.log.Log
    public void logTrace(Object message) {
        logInternal(TRACE, message, null);
    }

    @Override // com.mysql.jdbc.log.Log
    public void logTrace(Object message, Throwable exception) {
        logInternal(TRACE, message, exception);
    }

    @Override // com.mysql.jdbc.log.Log
    public void logWarn(Object message) {
        logInternal(WARN, message, null);
    }

    @Override // com.mysql.jdbc.log.Log
    public void logWarn(Object message, Throwable exception) {
        logInternal(WARN, message, exception);
    }

    private void logInternal(int level, Object msg, Throwable exception) {
        StringBuffer msgBuf = new StringBuffer();
        msgBuf.append(new Date().toString());
        msgBuf.append(" ");
        switch (level) {
            case FATAL /* 0 */:
                msgBuf.append("FATAL: ");
                break;
            case ERROR /* 1 */:
                msgBuf.append("ERROR: ");
                break;
            case WARN /* 2 */:
                msgBuf.append("WARN: ");
                break;
            case INFO /* 3 */:
                msgBuf.append("INFO: ");
                break;
            case DEBUG /* 4 */:
                msgBuf.append("DEBUG: ");
                break;
            case TRACE /* 5 */:
                msgBuf.append("TRACE: ");
                break;
        }
        if (msg instanceof ProfilerEvent) {
            msgBuf.append(LogUtils.expandProfilerEventIfNecessary(msg));
        } else {
            if (this.logLocationInfo && level != TRACE) {
                Throwable locationException = new Throwable();
                msgBuf.append(LogUtils.findCallingClassAndMethod(locationException));
                msgBuf.append(" ");
            }
            if (msg != null) {
                msgBuf.append(String.valueOf(msg));
            }
        }
        if (exception != null) {
            msgBuf.append("\n");
            msgBuf.append("\n");
            msgBuf.append("EXCEPTION STACK TRACE:");
            msgBuf.append("\n");
            msgBuf.append("\n");
            msgBuf.append(Util.stackTraceToString(exception));
        }
        String messageAsString = msgBuf.toString();
        System.err.println(messageAsString);
        if (bufferedLog != null) {
            bufferedLog.append(messageAsString);
        }
    }
}
